%global namedreltag .Final
%global namedversion %{version}%{?namedreltag}

Name: jboss-jts
Version: 4.16.2
Release: 3%{?dist}
Summary: Distributed Transaction Manager
Group: Development/Libraries
License: LGPLv2+
URL: https://community.jboss.org/wiki/JBossJTS

# svn export http://anonsvn.jboss.org/repos/labs/labs/jbosstm/tags/JBOSSTS_4_16_2_Final/ jboss-jts-4.16.2
# find jboss-jts-4.16.2 -name '*.jar' -delete
# tar cafJ jboss-jts-4.16.2.tar.xz jboss-jts-4.16.2
Source0: %{name}-%{namedversion}.tar.xz

Source1: https://repository.jboss.org/nexus/service/local/repositories/releases/content/org/jboss/jbossts/jbossjta/%{namedversion}/jbossjta-%{namedversion}.pom
Source2: https://repository.jboss.org/nexus/service/local/repositories/releases/content/org/jboss/jbossts/jbossjta-integration/%{namedversion}/jbossjta-integration-%{namedversion}.pom 

# Patched Ant xml files
# Removed com.arjuna.ats.jta.distributed.SimpleIsolatedServers test
# Removed some tests as they fail with Byteman
Patch0: %{name}-%{namedversion}-build.patch

# Added support for JBoss publican style shipped in Fedora
Patch1: %{name}-%{namedversion}-publican.patch

# Removed ArjunaCore/arjuna/classes/com/arjuna/ats/arjuna/tools/stats/TxPerfGraph.java because we don't have orson packaged
Patch2: %{name}-%{namedversion}-orson.patch

# Removed ArjunaCore/arjuna/classes/com/arjuna/ats/internal/arjuna/objectstore/hornetq/* classes because we don't have hornetq
Patch3: %{name}-%{namedversion}-hornetq.patch

# Patch to remove hornetq dependency from the pom (SOURCE0)
Patch4: %{name}-%{namedversion}-pom.patch

# Patch to remove hornetq dependency from the integration pom (SOURCE1)
Patch5: %{name}-%{namedversion}-integration-pom.patch

BuildArch: noarch

BuildRequires: jpackage-utils
BuildRequires: java-devel
BuildRequires: junit
BuildRequires: ant
BuildRequires: ant-junit
BuildRequires: ant-contrib
BuildRequires: emma
BuildRequires: byteman
BuildRequires: jboss-logging
BuildRequires: jboss-logging-tools
BuildRequires: jboss-connector-1.6-api
BuildRequires: jboss-transaction-1.1-api
BuildRequires: jboss-transaction-spi
BuildRequires: jfreechart
BuildRequires: publican-jboss
BuildRequires: java-service-wrapper

Requires: jpackage-utils
Requires: java
Requires: byteman
Requires: emma
Requires: jboss-logging
Requires: jboss-logging-tools
Requires: jboss-connector-1.6-api
Requires: jboss-transaction-1.1-api
Requires: jboss-transaction-spi
Requires: jfreechart
Requires: java-service-wrapper


%description
A set of JBoss modules that fully supports ACID transactions
spread across multiple resource managers and application servers.
It implements a Distributed Transaction Manager (DTM) with support
for two-phase commit (2PC) across XA resource managers, JBoss
server instances, and CORBA OTS resources.

JBossJTS implements the Java Transaction Service (JTS) and CORBA
Transaction Service (OTS) specifications.


%package javadoc
Summary: Javadocs for %{name}
Group: Documentation
Requires: jpackage-utils


%description javadoc
This package contains the API documentation for %{name}.


%prep

# Extract the source:
%setup -q -n %{name}-%{namedversion}

# Put the POM files in place now, as they require patching:
cp %{SOURCE1} jbossjta.pom
cp %{SOURCE2} jbossjta-integration.pom

# Apply the patches:
%patch0 -p1
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p0
%patch5 -p0


%build

# Replace jar files with symlinks to their actual locations:
while read jar_name jar_path
do
  jar_file=$(build-classpath ${jar_name})
  jar_dir=$(dirname ${jar_path})
  if [ ! -d ${jar_dir} ]
  then
    mkdir -p ${jar_dir}
  fi
  ln -s ${jar_file} ${jar_path}
done <<'.'
junit common/lib/ext/junit.jar
junit ext/junit.jar
emma ext/emma.jar
emma_ant ext/emma_ant.jar
jboss-logging ext/jboss-logging.jar
jboss-logging-processor ext/jboss-logging-processor.jar
jboss-connector-1.6-api ext/ironjacamar-spec-api.jar
jboss-transaction-1.1-api ext/jboss-transaction-api_1.1_spec.jar
byteman/byteman ext/byteman.jar
byteman/byteman-bmunit ext/byteman-bmunit.jar
byteman/byteman-dtest ext/byteman-dtest.jar
byteman/byteman-install ext/byteman-install.jar
byteman/byteman-submit ext/byteman-submit.jar
jboss-transaction-spi ext/jboss-transaction-spi.jar
jfreechart/jfreechart ext/jfreechart-1.0.6.jar
.

# The above loop does not work for java service wrapper as the jar file is not
# installed in the expected location:
ln -s %{_libdir}/java-service-wrapper/wrapper.jar ext/wrapper.jar

# Build the binaries:
ant jbossjta

# Build the documentation:
ant \
  -f docs/build.xml \
  install.docs \
  install.common.docs

# Move the HTML documentation to the same directory that contains the PDF
# files:
documents='
development_guide
failure_recovery_guide
transactions_overview_guide
txbridge_guide
'
for document in ${documents}
do
  mkdir -p docs/build/install/docs/${document}
  mv docs/${document}/target/publican/en-US/html/* docs/build/install/docs/${document}
done

# Release notes are placed in a different directory, so move them to the same
# directory than the rest of the documentation:
mv docs/build/release_notes/en-US/pdf/*.pdf docs/build/install/docs/.
mkdir -p docs/build/install/docs/release_notes
cp -rp docs/build/release_notes/en-US/html/* docs/build/install/docs/release_notes


%install

# Jar files:
install -d -m 755 %{buildroot}%{_javadir}/%{name}
install -pm 644 install/lib/jbossjta.jar %{buildroot}%{_javadir}/%{name}/jbossjta.jar
install -pm 644 install/lib/jbossjta-integration.jar %{buildroot}%{_javadir}/%{name}/jbossjta-integration.jar

# No POM's for these files:
install -pm 644 install/services/lib/jbossjta-services.jar %{buildroot}%{_javadir}/%{name}/jbossjta-services.jar

# POM files:
install -d -m 755 %{buildroot}%{_mavenpomdir}
install -pm 644 jbossjta.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-jbossjta.pom
install -pm 644 jbossjta-integration.pom %{buildroot}%{_mavenpomdir}/JPP.%{name}-jbossjta-integration.pom

# Dependencies map:
%add_maven_depmap JPP.%{name}-jbossjta.pom %{name}/jbossjta.jar
%add_maven_depmap JPP.%{name}-jbossjta-integration.pom %{name}/jbossjta-integration.jar

# Javadoc files:
install -d -m 755 %{buildroot}%{_javadocdir}/%{name}
cp -rp install/htdocs/* %{buildroot}%{_javadocdir}/%{name}


%files
%{_mavenpomdir}/*
%{_mavendepmapfragdir}/*
%{_javadir}/*
%doc docs/build/install/docs/*


%files javadoc
%{_javadocdir}/%{name}


%changelog
* Tue Mar 20 2012 Juan Hernandez <juan.hernandez@redhat.com> 4.16.2-3
- Use the namedversion macro in the source URLs
- Fixed the version numbers in the changelog

* Tue Mar 20 2012 Juan Hernandez <juan.hernandez@redhat.com> 4.16.2-2
- Cleanup of the spec file

* Mon Nov 21 2011 Marek Goldmann <mgoldman@redhat.com> 4.16.2-1
- Initial packaging

